Please see [https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-models/get-ml-model-bert-base-squad](https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-models/get-ml-model-bert-base-squad) for the documentation of this CM script.
